Coverage for girder/api/api_main: 96%

# Coverage for girder/api/api_main : 96%

## 23 statements 22 run 1 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 | #!/usr/bin/env python # -*- coding: utf-8 -*- ############################################################################### # Copyright 2013 Kitware Inc. # # Licensed under the Apache License, Version 2.0 ( the "License" ); # you may not use this file except in compliance with the License. # You may obtain a copy of the License at # # http://www.apache.org/licenses/LICENSE-2.0 # # Unless required by applicable law or agreed to in writing, software # distributed under the License is distributed on an "AS IS" BASIS, # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. # See the License for the specific language governing permissions and # limitations under the License. ############################################################################### from . import describe from v1 import assetstore, file, collection, folder, group, item, resource,\ system, user class ApiDocs(): exposed = True def GET(self): # TODO return "should display links to available api versions" def addApiToNode(node): node.api = ApiDocs() _addV1ToNode(node.api) return node def _addV1ToNode(node): node.v1 = describe.ApiDocs() node.v1.describe = describe.Describe() node.v1.assetstore = assetstore.Assetstore() node.v1.collection = collection.Collection() node.v1.file = file.File() node.v1.folder = folder.Folder() node.v1.group = group.Group() node.v1.item = item.Item() node.v1.resource = resource.Resource() node.v1.system = system.System() node.v1.user = user.User() return node